//---------------------------------------------------------------------------

#include <vcl.h>
#pragma hdrstop

#include "ProxyFrames.h"
#include "ProxyDlgs.h"
#include "PrintProxyDlgs.h"
#include "Images256s.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma link "QSFrames"
#pragma resource "*.dfm"
TProxiesFrame *ProxiesFrame;
//---------------------------------------------------------------------------

TQSFrame* __fastcall OpenProxiesFrame(TForm *Owner, TPanel *Parent, const AnsiString &Path,
   TGlobal *global)
{
   assert(Owner != NULL && Parent != NULL && Path != "" && global != NULL);
   Global = global;

   ProxiesFrame = new TProxiesFrame(Owner, Parent, Path);
   return ProxiesFrame;
}
//---------------------------------------------------------------------------

void __fastcall DeleteProxiesFrame(TQSFrame *Frame)
{
   delete Frame;
}
//---------------------------------------------------------------------------

__fastcall TProxiesFrame::TProxiesFrame(TComponent* Owner)
        : TQSFrame(Owner)
{
}
//---------------------------------------------------------------------------

__fastcall TProxiesFrame::TProxiesFrame(TComponent *Owner, TPanel *Parent, const AnsiString &Path)
        : TQSFrame(Owner, Parent, Path)
{
   WM_QSAPPMESSAGE = RegisterWindowMessage(WM_QSAppMessage.c_str());

   ToolBar->DisabledImages = Images256->ProxyDisabled;
   ToolBar->HotImages = Images256->ProxyHot;
   ToolBar->Images = Images256->Proxy;

   ListView->SmallImages = Images256->ProxyListTiny;
   ListView->LargeImages = Images256->ProxyList;

   LoadIndex(Path);
}
//---------------------------------------------------------------------------

__fastcall TProxiesFrame::~TProxiesFrame()
{
}
//---------------------------------------------------------------------------

int __fastcall TProxiesFrame::DataTypeImageIndex(TDataType Type)
{
   return 0;
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::LoadIndex(AnsiString path)
{
   ListView->Items->Clear();

   if (path.Pos(QSHome) == 1)
      path = path.SubString(QSHome.Length()+2, 256);

   AnsiString value;
   TStringList *proxies = new TStringList();
   Global->DB->GetProxies(proxies);

   for (int i = 0; i < proxies->Count; i++)
   {
      AnsiString proxy = proxies->Strings[i];
      TListItem *item = ListView->Items->Add();

      item->Caption = GetTok(0, proxy, ProxyDiv);

      int i = 1; while ((value = GetTok(i, proxy, ProxyDiv)) != "")
      {
         if (value == " " || value == "<none>")
            value = "--";
         item->SubItems->Add(value);
         i++;
      }
      item->SubItems->Add(proxy);
   }

   SetProxyButtons();
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::ProxiesNewItemClick(TObject *)
{
   NewProxy();
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::ProxiesOpenItemClick(TObject *)
{
   assert(ListView->Selected != NULL);

   OpenSelectedProxy();
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::ProxiesDeleteItemClick(TObject *)
{
   assert(ListView->Selected != NULL);

   DeleteSelectedProxies();
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::ListViewClick(TObject *)
{
//   SetProxyButtons();
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::ListViewChange(TObject *Sender,
      TListItem *Item, TItemChange Change)
{
   SetProxyButtons();
}
//---------------------------------------------------------------------------

AnsiString __fastcall TProxiesFrame::IndexStr(TListItem *Item)
{
   assert(Item != NULL && Item->SubItems->Count > 0);

   return Item->SubItems->Strings[Item->SubItems->Count - 1];
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::SetProxyButtons()
{
   NewBtn->Enabled = true;
   DeleteBtn ->Enabled = ListView->SelCount > 0;
   OpenBtn->Enabled = ListView->SelCount == 1;
   PrintBtn->Enabled = ListView->Items->Count > 0;
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::ProxiesMenuClick(TObject *)
{
   ProxiesDeleteItem->Enabled = ListView->SelCount > 0;
   ProxiesOpenItem->Enabled = ListView->SelCount == 1;
   ProxiesSelectAllItem->Enabled = ListView->Items->Count > 0;
   ProxiesPrintItem->Enabled = ListView->Items->Count > 0;
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::PopProxyMenuPopup(TObject *)
{
   PopProxyNewItem->Enabled = true;
   PopProxyOpenItem->Enabled = ListView->SelCount == 1;
   PopProxySelectAllItem->Enabled = ListView->Items->Count > 0;
   PopProxyPrintItem->Enabled = ListView->Items->Count > 0;
   PopProxyDeleteItem->Enabled = ListView->SelCount > 0;
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::NewProxy()
{
   assert(Path != "");

   if (SecureModeMsg(Application->MainForm))
      return;

   AnsiString proxy = OpenProxyDialog(Application->MainForm, "");
   if (!proxy.IsEmpty())
   {
      if (SecureModeMsg(Application->MainForm))
         return;

      ListView->Items->BeginUpdate();
      LoadIndex(Path);

      for (int i = 0; i < ListView->Items->Count; i++)
      {
         TListItem *Item = ListView->Items->Item[i];
         if (IndexStr(Item) == proxy)
         {
            ListView->Selected = Item;
            Item->MakeVisible(false);
            break;
         }
      }

      ListView->Items->EndUpdate();
      PostMessage(HWND_BROADCAST, WM_QSAPPMESSAGE, QSMSGID_LOADPROXIES, 0);
   }
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::OpenSelectedProxy()
{
   assert(ListView->Selected != NULL);
   OpenProxy(IndexStr(ListView->Selected));
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::OpenProxy(AnsiString Proxy)
{
   assert(Proxy != "");

   if (SecureModeMsg(Application->MainForm))
      return;

   AnsiString proxy = OpenProxyDialog(Application->MainForm, Proxy);
   if (proxy != "")
   {
      if (SecureModeMsg(Application->MainForm))
         return;

      ListView->Items->BeginUpdate();
      LoadIndex(Path);

      for (int i = 0; i < ListView->Items->Count; i++)
      {
         TListItem *Item = ListView->Items->Item[i];
         if (IndexStr(Item) == proxy)
         {
            Item->MakeVisible(false);
            break;
         }
      }

      ListView->Items->EndUpdate();
      PostMessage(HWND_BROADCAST, WM_QSAPPMESSAGE, QSMSGID_LOADPROXIES, 0);
   }
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::ProxiesSelectAllItemClick(TObject *)
{
   ListView->SelectAll();
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::ProxiesPrintItemClick(TObject *)
{
   OpenPrinterDialog(Application->MainForm, ListView);
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::DeleteSelectedProxies()
{
   assert(ListView->Selected != NULL);

   if (SecureModeMsg(Application->MainForm))
      return;

   AnsiString proxies = "proxy?";
   if (ListView->SelCount > 1) proxies = "proxies?";

   if (MsgBox(Application->MainForm, "Delete the selected " + proxies, MT_CONFIRM, MB_OKCANCEL) == IDOK)
   {
      ListView->Items->BeginUpdate();

      int i = 0; while (i < ListView->Items->Count)
      {
         TListItem *Item = ListView->Items->Item[i];
         if (Item->Selected)
         {
            Global->DB->DelProxy(IndexStr(Item));
            Item->Delete();
         }
         else i++;
      }

      ListView->Items->EndUpdate();
      PostMessage(HWND_BROADCAST, WM_QSAPPMESSAGE, QSMSGID_LOADPROXIES, 0);
   }
   SetProxyButtons();
}
//---------------------------------------------------------------------------

void __fastcall TProxiesFrame::DeleteProxy(AnsiString Proxy)
{
   if (SecureModeMsg(Application->MainForm))
      return;

   for (int i = 0; i < ListView->Items->Count; i++)
   {
     TListItem *Item = ListView->Items->Item[i];
     if (IndexStr(Item) == Proxy)
     {
        PostMessage(HWND_BROADCAST, WM_QSAPPMESSAGE, QSMSGID_LOADPROXIES, 0);
        Global->DB->DelProxy(IndexStr(Item));
        Item->Delete();
        break;
      }
   }
   SetProxyButtons();
}
//---------------------------------------------------------------------------


