//---------------------------------------------------------------------------

#include <vcl.h>
#pragma hdrstop

#include "QSProxyWins.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"

#include "Global2.h"
#include "ProxyDlgs.h"
#include "PrintProxyDlgs.h"
#include "ProxyFrames.h"
#include "AboutDlgs2.h"
#include "PrxyOptionsDlgs.h"
#include "QSproxyVer.h"
#include "Images256s.h"
#include "HistoryWins.h"

HWND HelpWin = 0;
const AnsiString AppHelpFile = ChangeFileExt(Application->ExeName, ".chm");
TQSProxyWin *QSProxyWin;
//---------------------------------------------------------------------------

__fastcall TQSProxyWin::TQSProxyWin(TComponent* Owner)
        : TForm(Owner)
{
   if (!FileExists(AppDat()) && FileExists(AppPGP()))
   {
      ShowMessage(
        "I find your QS database is encrypted. You need to   \n"
        "Start QS and decrypt the file.");
      Application->ShowMainForm = false;
      PostMessage(Handle, WM_QUIT, 0, 0);
      return;
   }

   if (!InitGlobal(this))
   {
      Application->ShowMainForm = false;
      PostMessage(Handle, WM_QUIT, 0, 0);
      return;
   }

   TIniFile *ini = new TIniFile(AppIni());

   if (ParamCount() > 0 && ParamStr(1).LowerCase().Pos("version") > 0)
   {
      ini->WriteString(ProxyIni, "version", ReleaseVersion);
      Application->ShowMainForm = false;
      PostMessage(Handle, WM_QUIT, 0, 0);
      delete ini;
      return;
   }

   Caption = "QuickSilver Proxy Manager " + ReleaseVersion;
   Bevel1->Align = alTop;
   NavBar->Align = alTop;
   Panel2->Align = alClient;
   AnsiString path = "/QuickSilver/Proxies";

   Images256 = new TImages256(this);

   Panel2->Color = (TColor)ini->ReadInteger(ProxyIni, QSWINDOWCOLOR, QSWINDOWCOLORDEF);
   StrToFont(ini->ReadString(ProxyIni, QSWINDOWFONT, QSWINDOWFONTDEF), Panel2->Font);
   // Set Panel2 font before init DetailFrame

   DetailFrame = (TProxiesFrame*)OpenProxiesFrame(this, Panel2, path, Global);
   DetailFrame->CoolBar->Parent = this;
   DetailFrame->ToolBar->Height = 30;
   DetailFrame->ToolBar->ButtonHeight = 28;
   DetailFrame->ToolButton14->Visible = true;
   //DetailFrame->HelpTopicsItem->Enabled = false;
   Menu = DetailFrame->Menu;

   CurPath->Caption = path;

   StrToFont(ini->ReadString(ProxyIni, QSDIALOGFONT, QSDIALOGFONTDEF), Font);
   DetailFrame->CoolBar->Visible = ini->ReadBool(ProxyIni, QSTOOLBAR, true);
   StatusBar->Visible = ini->ReadBool(ProxyIni, QSSTATUSBAR, true);
   NavBar->Visible = false; //ini->ReadBool(ProxyIni, QSNAVBAR, true);
   Bevel1->Visible = NavBar->Visible;

   LoadWindowPosition(this, ProxyIni, ini);

   delete ini;
   LoadHtmlHelp();
   Application->OnMessage = AppMessage;

   Snooze(50);
}
//---------------------------------------------------------------------------

__fastcall TQSProxyWin::~TQSProxyWin()
{
//
}
//---------------------------------------------------------------------------

void __fastcall TQSProxyWin::FormCloseQuery(TObject *, bool &)
{
   if (Application->MainForm->Visible)// if not, global init failed
   {
      TIniFile *ini = new TIniFile(AppIni());
      ini->WriteBool(ProxyIni, QSTOOLBAR, DetailFrame->CoolBar->Visible);
      //ini->WriteBool(ProxyIni, QSNAVBAR, NavBar->Visible);
      ini->WriteBool(ProxyIni, QSSTATUSBAR, StatusBar->Visible);
      SaveWindowPosition(this, ProxyIni, ini);
      delete ini;

      DeleteProxiesFrame(DetailFrame);
      delete Images256;
   }

   ShutDownGlobal();

   UnloadHtmlHelp();
}
//---------------------------------------------------------------------------

void __fastcall TQSProxyWin::AppMessage(tagMSG &Msg, bool &Handled)
{
   if (Msg.message == WM_QSAPPMESSAGE)
   {
      switch (Msg.wParam)
      {
         case QSMSGID_SHUTDOWN:
            Close();
            Handled = true;
            return;
      }
   }
}
//---------------------------------------------------------------------------

void __fastcall TQSProxyWin::WMOpenOptions(TMessage &)
{
   OpenProxyOptionsDialog(this, "QuickSilver Proxy Options");
}
//---------------------------------------------------------------------------

void __fastcall TQSProxyWin::WMOpenQuickStart(TMessage &)
{
   //
}
//---------------------------------------------------------------------------

void __fastcall TQSProxyWin::WMOpenHelpTopics(TMessage& Msg)
{
   AnsiString topic = AppHelpFile + ">qsproxyhelp";
   HelpWin = HTMLHelp(Handle, topic.c_str(), HH_DISPLAY_TOPIC, NULL);
}
//---------------------------------------------------------------------------

void __fastcall TQSProxyWin::WMOpenHistory(TMessage& Msg)
{
   AnsiString history = "qsproxy.history.txt";
   if (FileExists(AppDir() + history))
   {
      OpenApplicationHistory(this, DetailFrame->ListView->Font,
         DetailFrame->ListView->Color, AppDir() + history);
      return;
   }

   if (FileExists(AppDir() + "docs\\" + history))
   {
      OpenApplicationHistory(this, DetailFrame->ListView->Font,
         DetailFrame->ListView->Color, AppDir() + "docs\\" + history);
      return;
   }
}
//---------------------------------------------------------------------------

void __fastcall TQSProxyWin::WMShowAboutBox(TMessage &)
{
   ShowAboutBox(this, AppName + "  v" + ReleaseVersion);
}
//---------------------------------------------------------------------------

void __fastcall TQSProxyWin::WMGetViewMenu(TMessage &Msg)
{
   int flags = 0;
   if (StatusBar->Visible) flags |= flagStatusBar;
   if (NavBar->Visible) flags |= flagAddressBar;
   Msg.Result = flags;
}
//---------------------------------------------------------------------------

void __fastcall TQSProxyWin::WMSetViewMenu(TMessage &Msg)
{
   DetailFrame->ViewStatusBarItem->Checked = !DetailFrame->ViewStatusBarItem->Checked;
   StatusBar->Visible = DetailFrame->ViewStatusBarItem->Checked;
}
//---------------------------------------------------------------------------

void __fastcall TQSProxyWin::WMCloseApp(TMessage &)
{
   Close();
}
//---------------------------------------------------------------------------


